//
//      black-hole-mta - email goes in but nothing comes out
//      Copyright (C) 2007, 2011 Peter Miller
//
//      This program is free software; you can redistribute it and/or
//      modify it under the terms of the GNU General Public License as
//      published by the Free Software Foundation; either version 3 of
//      the License, or (at your option) any later version.
//
//      This program is distributed in the hope that it will be useful,
//      but WITHOUT ANY WARRANTY; without even the implied warranty of
//      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//      GNU General Public License for more details.
//
//      You should have received a copy of the GNU General Public License
//      along with this program. If not, see
//      <http://www.gnu.org/licenses/>.
//

#ifndef LIB_MAIL_TRANSFER_AGENT_BLACK_HOLE_H
#define LIB_MAIL_TRANSFER_AGENT_BLACK_HOLE_H

#include <lib/mail_transfer_agent.h>

/**
  * The mail_transfer_agent_black_hole class is used to represent a mail
  * transfer agent which immediately discards all email as if had been
  * sent. Email goes in but nothing comes out.
  */
class mail_transfer_agent_black_hole:
    public mail_transfer_agent
{
public:
    /**
      * The destructor.
      */
    virtual ~mail_transfer_agent_black_hole();

    /**
      * The default constructor.
      */
    mail_transfer_agent_black_hole();

protected:
    // See base class for documentation.
    void mailq();

    // See base class for documentation.
    void newaliases();

    // See base class for documentation.
    void send(const std::string &email_address, const std::string &filename);

    // See base class for documentation.
    void verify(const string_list_t &names);

    // See base class for documentation.
    void purge_host_status();

    // See base class for documentation.
    void print_host_status();

private:
    /**
      * The copy constructor.  Do not use.
      */
    mail_transfer_agent_black_hole(const mail_transfer_agent_black_hole &);

    /**
      * The assignment operator.  Do not use.
      */
    mail_transfer_agent_black_hole &operator=(
        const mail_transfer_agent_black_hole &);
};

// vim: set ts=8 sw=4 et :
#endif // LIB_MAIL_TRANSFER_AGENT_BLACK_HOLE_H
