//
// black-hole-mta - email goes in but nothing comes out
// Copyright (C) 2007, 2009, 2011, 2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <lib/config.h>
#include <cerrno>
#include <cstdio>
#include <cstring>
#include <libexplain/fclose.h>
#include <libexplain/fflush.h>
#include <libexplain/fgets.h>
#include <libexplain/fdopen.h>
#include <libexplain/mkstemp.h>
#include <libexplain/output.h>
#include <libexplain/program_name.h>
#include <libexplain/unlink.h>

#include <lib/mail_transfer_agent.h>
#include <lib/rfc822.h>


void
mail_transfer_agent::send_glue(const string_list_t &names)
{
    bool dot = !get_bool("no-dot");

    //
    // Read the email from the standard input
    // and put it into a temporary file.
    //
    char filename[100];
    const char *dir = getenv("TMP_DIR");
    if (!dir || *dir != '/')
        dir = "/tmp";
    strcpy(filename, dir);
    strcpy(filename, "/");
    strcpy(filename, explain_program_name_get());
    strcpy(filename, "-XXXXXX");
    int fd = explain_mkstemp_or_die(filename);
    FILE *fp = explain_fdopen_or_die(fd, "w");
    fd = -1;
    for (;;)
    {
        char buffer[1000];
        if (!explain_fgets_or_die(buffer, sizeof(buffer), stdin))
        {
            break;
        }
        size_t len = strlen(buffer);
        if (len > 0 && buffer[len - 1] == '\n')
            buffer[--len] = 0;
        if (len > 0 && buffer[len - 1] == '\r')
            buffer[--len] = 0;
        if (dot && buffer[0] == '.')
        {
            if (buffer[1] == 0)
                break;
            fputs(buffer + 1, fp);
        }
        else
        {
            fputs(buffer, fp);
        }
        putc('\n', fp);
    }
    if (fflush(fp))
    {
        int err = errno;
        unlink(filename);
        explain_output_error_and_die
        (
            "%s",
            explain_errno_fflush(err, fp)
        );
    }
    explain_fclose_or_die(fp);
    fp = 0;

    if (get_bool("recipients"))
    {
        rfc822 headers;
        headers.load(filename);
        std::string to = headers.get("to");
        if (to.empty())
            goto no_names;
        send(to, filename);
    }
    else if (names.empty())
    {
        no_names:
        unlink(filename);
        explain_output_error_and_die("no recipient on command line");
    }

    //
    // Now deliver it to each of the recipients.
    // This is virtual, behaviour depends on derived class.
    //
    for
    (
        string_list_t::const_iterator it = names.begin();
        it != names.end();
        ++it
    )
    {
        send(*it, filename);
    }

    //
    // get rid of the temporary file
    //
    explain_unlink_or_die(filename);
}


// vim: set ts=8 sw=4 et :
