//
// black-hole-mta - email goes in but nothing comes out
// Copyright (C) 2007, 2009, 2011, 2012 Peter Miller
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or (at
// your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

#include <lib/config.h>
#include <cstdio>
#include <cstring>
#include <libexplain/output.h>
#include <libexplain/program_name.h>

#include <lib/mail_transfer_agent.h>


mail_transfer_agent::be_method_pointer
mail_transfer_agent::sendmail_lookup(const char *name)
{
    if (0 == strcmp(name, "d") || 0 == strcasecmp(name, "daemon"))
        return &mail_transfer_agent::daemon_glue;
    if (0 == strcmp(name, "D") || 0 == strcasecmp(name, "daemon-no-fork"))
        return &mail_transfer_agent::daemon_nofork_glue;
    if (0 == strcmp(name, "H") || 0 == strcasecmp(name, "purge-host-status"))
        return &mail_transfer_agent::purge_host_status_glue;
    if (0 == strcmp(name, "h") || 0 == strcasecmp(name, "print-host-status"))
        return &mail_transfer_agent::print_host_status_glue;
    if (0 == strcasecmp(name, "i") || 0 == strcasecmp(name, "initialize"))
        return &mail_transfer_agent::newaliases_glue;
    if (0 == strcasecmp(name, "m") || 0 == strcasecmp(name, "send"))
        return &mail_transfer_agent::send_glue;
    if (0 == strcasecmp(name, "p") || 0 == strcasecmp(name, "list"))
        return &mail_transfer_agent::mailq_glue;
    if (0 == strcasecmp(name, "s") || 0 == strcasecmp(name, "server"))
        return &mail_transfer_agent::server_glue;
#if 0
    if (0 == strcasecmp(name, "t") || 0 == strcasecmp(name, "rule-test"))
        return &mail_transfer_agent::rule_test;
#endif
    if (0 == strcasecmp(name, "v") || 0 == strcasecmp(name, "verify"))
        return &mail_transfer_agent::verify;
    explain_output_error_and_die("action \"%s\" unknown", name);
    return &mail_transfer_agent::nop;
}


void
mail_transfer_agent::sendmail(int argc, char **argv)
{
    explain_program_name_set(argv[0]);
    be_method_pointer be = &mail_transfer_agent::send_glue;
    for (;;)
    {
        int c =
            getopt
            (
                argc,
                argv,
                "A:B:b:C:d:F:Gh:IiL:M:mN:nO:o:p:q:R:r:T:tUV:X:"
            );
        if (c == EOF)
            break;
        switch (c)
        {
        case 'A':
            // ignored
            break;

        case 'B':
            set("body-type", optarg);
            break;

        case 'b':
            be = sendmail_lookup(optarg);
            break;

        case 'C':
            set_configuration_file(optarg);
            break;

        case 'd':
            set("facility-level", optarg);
            break;

        case 'F':
            set("from", optarg);
            break;

        case 'f':
            set("sender", optarg);
            break;

        case 'G':
            set("gateway", true);
            break;

        case 'h':
            set("hop-count", optarg);
            break;

        case 'I':
            be = &mail_transfer_agent::newaliases_glue;
            break;

        case 'i':
            set("no-dot", true);
            break;

        case 'L':
            set("logging-label", optarg);
            break;

        case 'M':
        case 'O':
        case 'o':
            if (0 == strcmp("i", optarg))
                set("no-dot", true);
            else if (0 == strcmp("m", optarg))
                set("suppress-aliasing", true);
            else if (isdigit((unsigned char)*optarg))
                set("body-type", optarg);
            else
                parse_and_set(optarg);
            break;

        case 'm':
            // ignored
            break;

        case 'N':
            set("dsn", optarg);
            break;

        case 'n':
            set("suppress-aliasing", true);
            break;

        case 'p':
            set("protocol", optarg);
            break;

        case 'R':
            set("return-limit", optarg);
            break;

        case 'q':
            // ignored
            break;

        case 'r':
            set("error-to", optarg);
            break;

        case 'T':
            set("timeout.queuereturn", optarg);
            break;

        case 't':
            set("recipients", "true");
            break;

        case 'U':
            set("user-submission", true);
            break;

        case 'V':
            set("envid", optarg);
            break;

        case 'X':
            set("log-file", optarg);
            break;

        default:
            usage_with_names();
            // NOTREACHED
        }
    }

    //
    // Now pick the names of the command line.
    //
    string_list_t names;
    while (optind < argc)
        names.push_back(argv[optind++]);

    //
    // Call the appropriate method.
    //
    (this->*be)(names);
}


// vim: set ts=8 sw=4 et :
