#!/bin/sh
#
# black-hole-mta - email goes in but nothing comes out
# Copyright (C) 2007, 2011 Peter Miller
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
#
TEST_SUBJECT="server"

#
# The test prelude is common to all tests.  It creates a temporary
# diretcory and changes directory into it, so you can create temporary
# files to your heart's content.  It also loads our modules.  The
# functions "pass", "fail" and "no_result" are the only correct ways of
# leaving this test script.  The development directory is available via
# the $devdir variable, if you need data files or test programs.
#
# That dot means "include" in shell speak.  It has to be an include,
# executing it in a sub-shell will not work.
#
. test_prelude.inc

#
# Now test whatever it is you are testing.  Make sure you test ALL
# exit statuses, and report no_result for anything (anything at all)
# unexpected.
#
# Make sure that in the success case, your test is absolutely silent.
# Its tough enough figuring out what went wrong without having to wade
# through megabytes of verbal diarrhoea from tests which pass to find
# the one useful output indicating what failed.
#
cat > test.in << 'fubar'
HELO example.com
MAIL FROM:<nobody@example.com>
RCPT TO:<somebody@example.com>
DATA
Subject: test

test
.
QUIT
fubar
test $? -eq 0 || no_result

hostname=`hostname`
test $? -eq 0 || no_result

sed "s|hostname|$hostname|" > test.ok << 'fubar'
220 hostname
250 hostname
250 OK
250 OK
354 Send data, end with <CRLF>.<CRLF>
250 OK
221 Bye
fubar
test $? -eq 0 || no_result

sendmail -bs < test.in > test.out.raw
test $? -eq 0 || fail

tr -d '\15' < test.out.raw > test.out
test $? -eq 0 || no_result

diff test.ok test.out
test $? -eq 0 || fail

#
# All the things tested by this individual test passed.
# No other assertions are made.
#
pass

# vim: set ts=8 sw=4 et :
